@@ -21,80 +21,70 @@ import org.apache.commons.net.ftp.FTPFileEntryParser;
 
 /**
  */
-public abstract class CompositeFTPParseTestFramework extends FTPParseTestFramework
-{
-    public CompositeFTPParseTestFramework(String name)
-    {
+public abstract class CompositeFTPParseTestFramework extends AbstractFTPParseTest {
+    public CompositeFTPParseTestFramework(final String name) {
         super(name);
     }
 
     @Override
-    protected String[] getGoodListing()
-    {
-        return (getGoodListings()[0]);
+    protected String[] getBadListing() {
+        return getBadListings()[0];
     }
 
     /**
-     * Method getBadListing.
-     * Implementors must provide multiple listing that contains failures and
-     * must force the composite parser to switch the FtpEntryParser
+     * Method getBadListing. Implementors must provide multiple listing that contains failures and must force the composite parser to switch the FtpEntryParser
      *
      * @return String[]
      */
     protected abstract String[][] getBadListings();
 
+    @Override
+    protected String[] getGoodListing() {
+        return getGoodListings()[0];
+    }
+
     /**
-     * Method getGoodListing.
-     * Implementors must provide multiple listing that passes and
-     * must force the composite parser to switch the FtpEntryParser
+     * Method getGoodListing. Implementors must provide multiple listing that passes and must force the composite parser to switch the FtpEntryParser
      *
      * @return String[]
      */
     protected abstract String[][] getGoodListings();
 
-    @Override
-    protected String[] getBadListing()
-    {
-        return (getBadListings()[0]);
-    }
-
-    /* (non-Javadoc)
+    /*
+     * (non-Javadoc)
+     *
      * @see org.apache.commons.net.ftp.parser.FTPParseTestFramework#testGoodListing()
      */
-    public void testConsistentListing() throws Exception
-    {
-        String goodsamples[][] = getGoodListings();
+    @Override
+    public void testBadListing() {
+        final String badsamples[][] = getBadListings();
 
-        for (String[] goodsample : goodsamples)
-        {
-            FTPFileEntryParser parser = getParser();
-            for (String test : goodsample) {
-                FTPFile f = parser.parseFTPEntry(test);
-                assertNotNull("Failed to parse " + test,
-                        f);
+        for (final String[] badsample : badsamples) {
+            final FTPFileEntryParser parser = getParser();
+            for (final String test : badsample) {
+                final FTPFile f = parser.parseFTPEntry(test);
+                assertNull("Should have Failed to parse " + test, nullFileOrNullDate(f));
 
-                doAdditionalGoodTests(test, f);
+                doAdditionalBadTests(test, f);
             }
         }
     }
 
-    /* (non-Javadoc)
+    /*
+     * (non-Javadoc)
+     *
      * @see org.apache.commons.net.ftp.parser.FTPParseTestFramework#testGoodListing()
      */
-    @Override
-    public void testBadListing() throws Exception
-    {
-        String badsamples[][] = getBadListings();
+    public void testConsistentListing() {
+        final String goodsamples[][] = getGoodListings();
 
-        for (String[] badsample : badsamples)
-        {
-            FTPFileEntryParser parser = getParser();
-            for (String test : badsample) {
-                FTPFile f = parser.parseFTPEntry(test);
-                assertNull("Should have Failed to parse " + test,
-                        nullFileOrNullDate(f));
+        for (final String[] goodsample : goodsamples) {
+            final FTPFileEntryParser parser = getParser();
+            for (final String test : goodsample) {
+                final FTPFile f = parser.parseFTPEntry(test);
+                assertNotNull("Failed to parse " + test, f);
 
-                doAdditionalBadTests(test, f);
+                doAdditionalGoodTests(test, f);
             }
         }
     }
@@ -102,19 +92,16 @@ public abstract class CompositeFTPParseTestFramework extends FTPParseTestFramewo
     // even though all these listings are good using one parser
     // or the other, this tests that a parser that has succeeded
     // on one format will fail if another format is substituted.
-    public void testInconsistentListing() throws Exception
-    {
-        String goodsamples[][] = getGoodListings();
+    public void testInconsistentListing() {
+        final String goodsamples[][] = getGoodListings();
 
-        FTPFileEntryParser parser = getParser();
+        final FTPFileEntryParser parser = getParser();
 
-        for (int i = 0; i < goodsamples.length; i++)
-        {
-            String test = goodsamples[i][0];
-            FTPFile f = parser.parseFTPEntry(test);
+        for (int i = 0; i < goodsamples.length; i++) {
+            final String test = goodsamples[i][0];
+            final FTPFile f = parser.parseFTPEntry(test);
 
-            switch (i)
-            {
+            switch (i) {
             case 0:
                 assertNotNull("Failed to parse " + test, f);
                 break;
