@@ -15,28 +15,35 @@
  * limitations under the License.
  */
 package org.apache.commons.net.ftp.parser;
+
+import static org.junit.jupiter.api.Assertions.assertThrows;
+
 import junit.framework.TestCase;
 
 import org.apache.commons.net.ftp.FTPClientConfig;
 import org.apache.commons.net.ftp.FTPFileEntryParser;
 
+public class DefaultFTPFileEntryParserFactoryTest extends TestCase {
+    private void checkParserClass(final FTPFileEntryParserFactory fact, final String key, final Class<?> expected) {
+        final FTPClientConfig config = key == null ? new FTPClientConfig() : new FTPClientConfig(key);
+        final FTPFileEntryParser parser = fact.createFileEntryParser(config);
+        assertNotNull(parser);
+        assertTrue("Expected " + expected.getCanonicalName() + " got " + parser.getClass().getCanonicalName(), expected.isInstance(parser));
+    }
 
-public class DefaultFTPFileEntryParserFactoryTest extends TestCase
-{
-    public void testDefaultParserFactory() throws Exception {
-        final DefaultFTPFileEntryParserFactory factory =
-            new DefaultFTPFileEntryParserFactory();
+    public void testDefaultParserFactory() {
+        final DefaultFTPFileEntryParserFactory factory = new DefaultFTPFileEntryParserFactory();
 
         FTPFileEntryParser parser = factory.createFileEntryParser("unix");
         assertTrue(parser instanceof UnixFTPEntryParser);
 
         parser = factory.createFileEntryParser("UNIX");
         assertTrue(parser instanceof UnixFTPEntryParser);
-        assertFalse(((UnixFTPEntryParser)parser).trimLeadingSpaces);
+        assertFalse(((UnixFTPEntryParser) parser).trimLeadingSpaces);
 
         parser = factory.createFileEntryParser("UNIX_LTRIM");
         assertTrue(parser instanceof UnixFTPEntryParser);
-        assertTrue(((UnixFTPEntryParser)parser).trimLeadingSpaces);
+        assertTrue(((UnixFTPEntryParser) parser).trimLeadingSpaces);
 
         parser = factory.createFileEntryParser("Unix");
         assertTrue(parser instanceof UnixFTPEntryParser);
@@ -54,8 +61,7 @@ public class DefaultFTPFileEntryParserFactoryTest extends TestCase
             fail("Exception should have been thrown. \"NT\" is not a recognized key");
         } catch (final ParserInitializationException pie) {
             assertNull(pie.getCause());
-            assertTrue(pie.getMessage()+ "should contain 'Unknown parser type:'",
-                    pie.getMessage().contains("Unknown parser type:"));
+            assertTrue(pie.getMessage() + "should contain 'Unknown parser type:'", pie.getMessage().contains("Unknown parser type:"));
         }
 
         parser = factory.createFileEntryParser("WindowsNT");
@@ -73,7 +79,7 @@ public class DefaultFTPFileEntryParserFactoryTest extends TestCase
         parser = factory.createFileEntryParser("AS/400");
         assertTrue(parser instanceof CompositeFileEntryParser);
 
-        // Added test to make sure it handles the Unix systems that were
+        // Added test to make sure it handles the UNIX systems that were
         // compiled with OS as "UNKNOWN". This test validates that the
         // check is case-insensitive.
         parser = factory.createFileEntryParser("UNKNOWN Type: L8");
@@ -85,54 +91,36 @@ public class DefaultFTPFileEntryParserFactoryTest extends TestCase
             assertNull(pie.getCause());
         }
 
-        parser = factory.createFileEntryParser(
-            "org.apache.commons.net.ftp.parser.OS2FTPEntryParser");
+        parser = factory.createFileEntryParser("org.apache.commons.net.ftp.parser.OS2FTPEntryParser");
         assertTrue(parser instanceof OS2FTPEntryParser);
 
         try {
-            factory.createFileEntryParser(
-                "org.apache.commons.net.ftp.parser.DefaultFTPFileEntryParserFactory");
+            factory.createFileEntryParser("org.apache.commons.net.ftp.parser.DefaultFTPFileEntryParserFactory");
             fail("Exception should have been thrown. \"DefaultFTPFileEntryParserFactory\" does not implement FTPFileEntryParser");
         } catch (final ParserInitializationException pie) {
-            final Throwable root = pie.getCause();
-            assertTrue(root instanceof ClassCastException);
+            assertTrue(pie.getCause() instanceof ClassCastException);
         }
 
         try {
             // Class exists, but is an interface
             factory.createFileEntryParser("org.apache.commons.net.ftp.parser.FTPFileEntryParserFactory");
             fail("ParserInitializationException should have been thrown.");
-        } catch (final ParserInitializationException pie){
-            final Throwable root = pie.getCause();
-            assertTrue(root instanceof InstantiationException);
+        } catch (final ParserInitializationException pie) {
+            assertTrue(pie.getCause().toString(), pie.getCause() instanceof ReflectiveOperationException);
         }
         try {
             // Class exists, but is abstract
             factory.createFileEntryParser("org.apache.commons.net.ftp.FTPFileEntryParserImpl");
             fail("ParserInitializationException should have been thrown.");
-        } catch (final ParserInitializationException pie){
-            final Throwable root = pie.getCause();
-            assertTrue(root instanceof InstantiationException);
+        } catch (final ParserInitializationException pie) {
+            assertTrue(pie.getCause() instanceof InstantiationException);
         }
     }
 
-    private void checkParserClass(final FTPFileEntryParserFactory fact, final String key, final Class<?> expected){
-        final FTPClientConfig config = key == null ? new FTPClientConfig() : new FTPClientConfig(key);
-        final FTPFileEntryParser parser = fact.createFileEntryParser(config);
-        assertNotNull(parser);
-        assertTrue("Expected "+expected.getCanonicalName()+" got "+parser.getClass().getCanonicalName(),
-                expected.isInstance(parser));
-    }
     public void testDefaultParserFactoryConfig() throws Exception {
-        final DefaultFTPFileEntryParserFactory factory =
-            new DefaultFTPFileEntryParserFactory();
+        final DefaultFTPFileEntryParserFactory factory = new DefaultFTPFileEntryParserFactory();
 
-        try {
-            factory.createFileEntryParser((FTPClientConfig)null);
-            fail("Expected NullPointerException");
-        } catch (final NullPointerException npe) {
-            // expected
-        }
+        assertThrows(NullPointerException.class, () -> factory.createFileEntryParser((FTPClientConfig) null));
         checkParserClass(factory, null, UnixFTPEntryParser.class);
 
         checkParserClass(factory, FTPClientConfig.SYST_OS400, OS400FTPEntryParser.class);
